@@ -59,7 +59,7 @@ class TaskModel:
         log.info("num trainable params:" + str(self.model.num_parameters(only_trainable=True)))
 
         log.info("Model Parameters Details: ")
-        for name, param in self.model.num_parameters():
+        for name, param in self.model.named_parameters():
             log.info("{}:{}".format(name, param.size()))
 
     def _build_task_model(self, modelArgs, model_class=None):
